@@ -4,6 +4,8 @@
 srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
+olddir=`pwd`
+
 PKG_NAME="totem"
 ACLOCAL_FLAGS="-I libgd $ACLOCAL_FLAGS"
 
@@ -13,6 +15,7 @@ ACLOCAL_FLAGS="-I libgd $ACLOCAL_FLAGS"
     exit 1
 }
 
+cd "$srcdir"
 echo "+ Setting up submodules"
 git submodule update --init --recursive
 
@@ -21,4 +24,5 @@ which gnome-autogen.sh || {
 	exit 1
 }
 
+cd "$olddir"
 REQUIRED_PKG_CONFIG_VERSION=0.17.1 REQUIRED_AUTOMAKE_VERSION=1.11 USE_GNOME2_MACROS=1 . gnome-autogen.sh --enable-debug "$@"
