@@ -67,6 +67,7 @@ struct _TotemGriloPrivate {
 	gboolean plugins_loaded;
 
 	GrlSource *local_metadata_src;
+	GrlSource *title_parsing_src;
 	GrlSource *metadata_store_src;
 	GrlSource *bookmarks_src;
 	gboolean fs_plugin_configured;
@@ -337,7 +338,7 @@ can_remove (GrlSource *source,
 		return CAN_REMOVE_TRUE;
 	if (!media)
 		goto fallback;
-	if (GRL_IS_MEDIA_BOX (media))
+	if (grl_media_is_container (media))
 		return CAN_REMOVE_FALSE;
 	url = grl_media_get_url (media);
 	if (!url)
@@ -579,6 +580,11 @@ add_local_metadata (TotemGrilo *self,
 
 	options = grl_operation_options_new (NULL);
 	grl_operation_options_set_resolution_flags (options, GRL_RESOLVE_NORMAL);
+	grl_source_resolve_sync (self->priv->title_parsing_src,
+				 media,
+				 self->priv->metadata_keys,
+				 options,
+				 NULL);
 	grl_source_resolve_sync (self->priv->local_metadata_src,
 				 media,
 				 self->priv->metadata_keys,
@@ -688,13 +694,13 @@ browse_cb (GrlSource    *source,
 					    -1);
 		}
 
-		if (GRL_IS_MEDIA_IMAGE (media) ||
-		    GRL_IS_MEDIA_AUDIO (media)) {
+		if (grl_media_is_image (media) ||
+		    grl_media_is_audio (media)) {
 			/* This isn't supposed to happen as we filter for videos */
 			g_assert_not_reached ();
 		}
 
-		if (GRL_IS_MEDIA_BOX (media) && bud->ignore_boxes) {
+		if (grl_media_is_container (media) && bud->ignore_boxes) {
 			/* Ignore boxes for certain sources */
 		} else {
 			add_local_metadata (self, source, media);
@@ -815,8 +821,8 @@ search_cb (GrlSource    *source,
 	if (media != NULL) {
 		self->priv->search_remaining--;
 
-		if (GRL_IS_MEDIA_IMAGE (media) ||
-		    GRL_IS_MEDIA_AUDIO (media)) {
+		if (grl_media_is_image (media) ||
+		    grl_media_is_audio (media)) {
 			/* This isn't supposed to happen as we filter for videos */
 			g_assert_not_reached ();
 		}
@@ -1000,7 +1006,7 @@ browser_activated_cb (GdMainView  *view,
 	                    -1);
 
 	/* Activate an item */
-	if (content != NULL && GRL_IS_MEDIA_BOX (content) == FALSE) {
+	if (content != NULL && grl_media_is_container (content) == FALSE) {
 		play (self, source, content, TRUE);
 		goto free_data;
 	}
@@ -1268,7 +1274,9 @@ source_added_cb (GrlRegistry *registry,
 		name = grl_source_get_name (source);
 
 	/* Metadata */
-	if (g_str_equal (id, "grl-local-metadata"))
+	if (g_str_equal (id, "grl-video-title-parsing"))
+		self->priv->title_parsing_src = source;
+	else if (g_str_equal (id, "grl-local-metadata"))
 		self->priv->local_metadata_src = source;
 	else if (g_str_equal (id, "grl-metadata-store"))
 		self->priv->metadata_store_src = source;
@@ -1425,7 +1433,7 @@ load_grilo_plugins (TotemGrilo *self)
 	g_signal_connect (registry, "source-removed",
 	                  G_CALLBACK (source_removed_cb), self);
 
-	if (grl_registry_load_all_plugins (registry, &error) == FALSE) {
+	if (grl_registry_load_all_plugins (registry, TRUE, &error) == FALSE) {
 		g_warning ("Failed to load grilo plugins: %s", error->message);
 		g_error_free (error);
 	}
@@ -1512,7 +1520,7 @@ get_more_browse_results_cb (GtkAdjustment *adjustment,
 		                    -1);
 		/* Skip non-boxes (they can not be browsed) */
 		if (container != NULL &&
-		    GRL_IS_MEDIA_BOX (container) == FALSE) {
+		    grl_media_is_container (container) == FALSE) {
 			goto free_elements;
 		}
 
@@ -2179,6 +2187,7 @@ setup_browse (TotemGrilo *self)
 {
 	GtkAdjustment *adj;
 	const char const * select_all_accels[] = { "<Primary>A", NULL };
+	const char const * select_none_accels[] = { "<Shift><Primary>A", NULL };
 
 	/* Search */
 	gtk_search_bar_connect_entry (GTK_SEARCH_BAR (self->priv->search_bar),
@@ -2208,6 +2217,7 @@ setup_browse (TotemGrilo *self)
 	g_signal_connect (G_OBJECT (self->priv->select_none_action), "activate",
 			  G_CALLBACK (select_none_action_cb), self);
 	g_action_map_add_action (G_ACTION_MAP (self->priv->totem), G_ACTION (self->priv->select_none_action));
+	gtk_application_set_accels_for_action (GTK_APPLICATION (self->priv->totem), "app.select-none", select_none_accels);
 	g_object_bind_property (self->priv->header, "select-mode",
 				self->priv->select_none_action, "enabled",
 				G_BINDING_SYNC_CREATE);
